@@ -59,6 +59,7 @@ import requests
 import json
 import copy
 import subprocess
+import signal
 
 from docopt import docopt
 import colorlog
@@ -73,7 +74,10 @@ try:
 except:
     sys.exit("Can not run, `git` must be installed on the system.")
 
-from .__version__ import __version__  # noqa: I900
+try:
+    from builder.__version__ import __version__  # noqa: I900
+except:
+    __version__ = "LOCAL DEV"
 from .prompt import prompt, yesno, prompt_list
 
 SSH_KEY_FILE_ENV = "SSH_KEY_FILE"
@@ -85,6 +89,14 @@ API_TOKEN = "eyJhbGciOiJSUzI1NiIsInR5cCI6IkpXVCJ9.eyJhcGkiOjEsImdycCI6MSwiaWF0Ij
 _LOGGER = logging.getLogger(__name__)
 
 
+cleanup_resources = {
+    "container": None,
+    "volume": None,
+    "network": None,
+    "build_dir": None,
+}
+
+
 def _make_opts(args):
 
     opts = {}
@@ -225,9 +237,12 @@ def stop_container(container, **kwargs):
     container.stop()
 
 
-def delete_container(container, **kwargs):
+def delete_container(container, force=False, **kwargs):
+    if not container:
+        return
+
     _LOGGER.info("Deleteing setup container...")
-    container.remove()
+    container.remove(force=force)
 
 
 def generate_random_string(length=10):
@@ -258,6 +273,9 @@ def push_image(
 
 
 def delete_volume(volume, **kwargs):
+    if not volume:
+        return
+
     _LOGGER.info("Deleteing setup volume...")
     volume.remove()
 
@@ -299,6 +317,9 @@ def setup_tmp_build(**kwargs):
 
 
 def cleanup_build(dir):
+    if not dir:
+        return
+
     _LOGGER.info("removing temporary setup folder...")
     dir.cleanup()
 
@@ -693,14 +714,16 @@ def run(opts, **kwargs):
     if not opts["no_pull"]:
         fetch_latest(client, opts["base"])
 
-    network = create_network(client)
-
     this = None
     containerized = check_if_container(client)
 
     realKey = sshKeyFile
+    network = None
     if containerized:
         _LOGGER.debug("Currently running in a docker container")
+        network = create_network(client)
+        cleanup_resources["network"] = network
+
         this = get_current_container(client)
         network.connect(this)
 
@@ -714,6 +737,9 @@ def run(opts, **kwargs):
         [realKey, sshKeyFile],
     )
 
+    cleanup_resources["volume"] = volume
+    cleanup_resources["container"] = container
+
     if containerized:
         network.connect(container)
 
@@ -736,6 +762,7 @@ def run(opts, **kwargs):
         return
 
     dir = setup_tmp_build()
+    cleanup_resources["build_dir"] = dir
 
     gitAuthentication = Authentication(
         opts["wiki_git_user"],
@@ -836,12 +863,26 @@ def run(opts, **kwargs):
 
     if containerized:
         network.disconnect(this)
-    network.remove()
+        network.remove()
 
     _LOGGER.info("Done.")
 
 
+def signal_handler(sig, frame):
+    print("Gracefully cleaning up all resources shutdown....")
+
+    delete_container(cleanup_resources["container"], force=True)
+    delete_volume(cleanup_resources["volume"])
+    if cleanup_resources["network"]:
+        cleanup_resources["network"].remove()
+
+    cleanup_build(cleanup_resources["build_dir"])
+
+    sys.exit(1)
+
+
 def main():
+    signal.signal(signal.SIGINT, signal_handler)
     args = docopt(__doc__)
 
     if args["--debug"]:
